tests.test_version — imagedata 1.3.6 documentation

# Source code for tests.test_version

    #!/usr/bin/env python3

    import unittest
    import logging

    from .context import imagedata

    class TestVersion(unittest.TestCase):
        # @unittest.skip("skipping test_version")
        def test_version(self):
            log = logging.getLogger("TestVersion.test_version")
            log.debug("test_version")

            logging.debug('test_version: version {}'.format(imagedata.__version__))
            if imagedata.__version__ == 'unknown':
                raise ValueError('Version number is {}'.format(imagedata.__version__))

    if __name__ == '__main__':
        unittest.main()